@@ -215,9 +215,18 @@ class APIClient(json.JSONEncoder):
         results = _validate(resp).json()
 
         self.access_token = results["access_token"]
-        return resp
+        return results
 
     def token_for_code(self, code):
+        """
+        Exchange an authorization code for an access token
+
+        Args:
+            code (str): One-time authorization code from Nylas
+
+        Returns:
+            str: The access token
+        """
         self.send_authorization(code)
         return self.access_token
 
@@ -280,10 +289,16 @@ class APIClient(json.JSONEncoder):
         _validate(resp).json()
         return resp.json()
 
-    def token_info(self):
-        token_info_url = self.token_info_url.format(
-            client_id=self.client_id, account_id=self.account.id
-        )
+    def token_info(self, account_id=None):
+        token_info_url = ""
+        if account_id is not None:
+            token_info_url = self.token_info_url.format(
+                client_id=self.client_id, account_id=account_id
+            )
+        else:
+            token_info_url = self.token_info_url.format(
+                client_id=self.client_id, account_id=self.account.id
+            )
         headers = {"Content-Type": "application/json"}
         headers.update(self.admin_session.headers)
         resp = self.admin_session.post(
