@@ -1,3 +1,5 @@
+import hashlib
+import hmac
 from datetime import datetime
 from collections import defaultdict
 from enum import Enum
@@ -122,6 +124,8 @@ class RestfulModel(dict):
                 else:
                     attr_value = getattr(self, attr)
                 if attr_value is not None:
+                    if attr.startswith("_"):
+                        attr = attr[1:]
                     dct[attr] = attr_value
         for date_attr, iso_attr in self.cls.date_attrs.items():
             if date_attr in self.read_only_attrs and enforce_read_only is True:
@@ -353,6 +357,7 @@ class Thread(NylasAPIObject):
         "version",
         "_folders",
         "_labels",
+        "_messages",
         "received_recent_date",
         "has_attachments",
     ]
@@ -375,6 +380,8 @@ class Thread(NylasAPIObject):
 
     @property
     def messages(self):
+        if self._messages:
+            return [Message.create(self.api, **f) for f in self._messages]
         return self.child_collection(Message, thread_id=self.id)
 
     @property
@@ -975,6 +982,24 @@ class Webhook(NylasAPIObject):
             dct = NylasAPIObject.as_json(self, enforce_read_only)
         return dct
 
+    @staticmethod
+    def verify_webhook_signature(nylas_signature, raw_body, client_secret):
+        """
+        Verify incoming webhook signature came from Nylas
+
+        Args:
+            nylas_signature (str): The signature to verify
+            raw_body (bytes | bytearray): The raw body from the payload
+            client_secret (str): Client secret of the app receiving the webhook
+
+        Returns:
+            bool: True if the webhook signature was verified from Nylas
+        """
+        digest = hmac.new(
+            str.encode(client_secret), msg=raw_body, digestmod=hashlib.sha256
+        ).hexdigest()
+        return hmac.compare_digest(digest, nylas_signature)
+
     class Trigger(str, Enum):
         """
         This is an Enum representing all the possible webhook triggers
