@@ -545,6 +545,22 @@ def mock_labelled_thread(mocked_responses, api_url, account_id):
                 "object": "label",
             },
         ],
+        "messages": [
+            {
+                "account_id": account_id,
+                "date": 1675274530,
+                "id": "222",
+                "labels": [
+                    {
+                        "display_name": "Trash",
+                        "id": "trash-id",
+                        "name": "trash",
+                    },
+                ],
+                "object": "message",
+                "thread_id": "111",
+            }
+        ],
         "first_message_timestamp": 1451703845,
         "last_message_timestamp": 1483326245,
         "last_message_received_timestamp": 1483326245,
@@ -1939,9 +1955,7 @@ def mock_ip_addresses(mocked_responses, api_url, client_id):
 
 @pytest.fixture
 def mock_token_info(mocked_responses, api_url, account_id, client_id):
-    token_info_url = "{base}/a/{client_id}/accounts/{id}/token-info".format(
-        base=api_url, id=account_id, client_id=client_id
-    )
+    token_info_url = re.compile(api_url + "/a/.*/accounts/.*/token-info")
     mocked_responses.add(
         responses.POST,
         token_info_url,
